@@ -11,9 +11,19 @@
 #' @export
 #' @examples
 #' pp_hpp(lambda = 1)
-
 pp_hpp <- function(lambda, events = NULL) {
   y <- c(list(lambda = lambda, events = events))
   class(y) <- "hpp"
   return(y)
 }
+
+
+#' @export
+print.hpp <- function(x, ...) {
+  cat("Homogeneous Poisson Process \n")
+  cat("lambda ", x$lambda0, "\n")
+  if(!(is.null(x$events))) {
+    cat("events", x$events, "\n") 
+  }
+  invisible(NULL)
+}
\ No newline at end of file
